pub fn check_win(
board: &Board,
coord: Coord,
player: Player,
win_length: u8,
) -> boolExpand description
Returns true if placing at coord for player creates a run of
at least win_length stones along any of the three hex axes.